@@ -5,7 +5,7 @@ then
 else
 	gconftool-2 --type bool --set /apps/mintdesktop-xfce/compiz_auto false
 fi
-if pidof compiz.real | grep [0-9] > /dev/null
+if pidof compiz | grep [0-9] > /dev/null
 then
 gconftool-2 --type bool --set /apps/mintdesktop-xfce/compiz_fusion true
 else
